// Get visitor's current location
        function getLocation(forceLocation) {
            return new Promise((resolve, reject) => {
                if (forceLocation && navigator.geolocation) {
                    navigator.geolocation.getCurrentPosition(
                        position => resolve(position.coords),
                        error => reject(error)
                    );
                } else {
                    fetch('https://nominatim.openstreetmap.org/?format=json&ip=<?php echo $ipAddress; ?>')
                        .then(response => response.json())
                        .then(data => {
                            if (data && data.lat && data.lon) {
                                resolve({
                                    latitude: parseFloat(data.lat),
                                    longitude: parseFloat(data.lon)
                                });
                            } else {
                                reject(new Error('Failed to retrieve location.'));
                            }
                        })
                        .catch(error => reject(error));
                }
            });
        }

        // Send location data to the server
        function sendLocationData(latitude, longitude, forceLocation) {
            return new Promise((resolve, reject) => {
                var xhr = new XMLHttpRequest();
                xhr.open('POST', 'index.php', true);
                xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                xhr.onreadystatechange = function () {
                    if (xhr.readyState === 4) {
                        if (xhr.status === 200) {
                            resolve();
                        } else {
                            reject(new Error('Failed to send location data.'));
                        }
                    }
                };
                xhr.send('latitude=' + latitude + '&longitude=' + longitude + '&forceLocation=' + (forceLocation ? '1' : '0'));
            });
        }

        // Update distances dynamically
        function updateDistances() {
            var distancesContainer = document.getElementById('distances-container');

            fetch('.php')
                .then(response => response.text())
                .then(html => {
                    distancesContainer.innerHTML = html;
                })
                .catch(error => {
                    distancesContainer.innerHTML = 'Error: ' + error.message;
                });
        }

        // Enforce location detection and auto-load distances
        function getLocationAndLoadDistances(forceLocation) {
    getLocation(forceLocation)
        .then(coords => {
            var { latitude, longitude } = coords;

            // Send location data to the server
            return sendLocationData(latitude, longitude, forceLocation);
        })
        .then(() => {
            // Refresh the page
            location.reload();
        })
        .catch(error => {
            console.log(error);
            var distancesContainer = document.getElementById('distances-container');
            distancesContainer.innerHTML = 'Error: ' + error.message;
        });
}

// Load distances on page load without forcing location
getLocationAndLoadDistances(false);
