<?php
require_once('../con/con.php');
session_start();

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    // User is not logged in, redirect to the login page
    header("Location: log.php");
    exit();
}

// Retrieve the user_id from the session
$user_id = $_SESSION['user_id'];

// Fetch the latest location data from the database
$stmt = $conn->prepare("SELECT * FROM locations WHERE user_id = ? ORDER BY timestamp DESC LIMIT 1");
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();
$location = $result->fetch_assoc();
$stmt->close();
?>

<!DOCTYPE html>
<html>
<head>
    <title>Dashboard</title>
    <script src="https://cdn.jsdelivr.net/npm/leaflet@1.7.1/dist/leaflet.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/leaflet@1.7.1/dist/leaflet.css" />
    <style>
        #map {
            height: 400px;
        }
    </style>
</head>
<body>
    <h2>Welcome to the Dashboard</h2>
    <div id="map"></div>

    <script>
        // Initialize the map
        var map = L.map('map').setView([0, 0], 2);

        // Create a tile layer with OpenStreetMap data
        L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
            attribution: '&copy; OpenStreetMap contributors'
        }).addTo(map);

        // Add a marker for the user's location
        var marker = L.marker([0, 0]).addTo(map);

        // Function to update the user's location on the map
        function updateLocation() {
            // Fetch the latest location data from the server
            fetch('get_latest_location.php?user_id=<?php echo $user_id; ?>')
                .then(response => response.json())
                .then(data => {
                    // Update the marker position with the new location
                    marker.setLatLng([data.latitude, data.longitude]);

                    // Center the map on the user's location
                    map.setView([data.latitude, data.longitude], map.getZoom());
                })
                .catch(error => {
                    console.error('Error:', error);
                });
        }

        // Update the user's location every 5 seconds
        setInterval(updateLocation, 5000);
    </script>
</body>
</html>
